about summary refs log tree commit diff
path: root/config.def.h
diff options
context:
space:
mode:
authorHiltjo Posthuma <hiltjo@codemadness.org>2015-05-04 21:54:46 +0200
committerAnselm R Garbe <garbeam@gmail.com>2015-06-27 21:47:10 +0200
commit4b1fecd44e8376594c418663351fcb30c4e841de (patch)
tree78db12fd7024bff8afb3c3bd8851c009837f5a34 /config.def.h
parentapplied Hiltjo's patch as suggested on the ml to fix ControlMask for C-j and C-m (diff)
downloaddmenu-4b1fecd44e8376594c418663351fcb30c4e841de.tar.gz
dmenu-4b1fecd44e8376594c418663351fcb30c4e841de.tar.bz2
dmenu-4b1fecd44e8376594c418663351fcb30c4e841de.zip
Use libdraw: add Xft and fallback-fonts support to graphics lib
- libdraw, util: add drw.{c,h}, util.{c,h} and update code.
- libdraw: fix drw_rect(): use w and h parameter.
- libdraw: print errstr if last character in string was ":" (sbase).
- libdraw: drw_clr_free() allow valid free(NULL).
- config.def.h: set default font to monospace.
- cleanup() on exit.
- LICENSE: update license string for dmenu -v to 2015.
- LICENSE: add myself to LICENSE
Diffstat (limited to 'config.def.h')
-rw-r--r--config.def.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/config.def.h b/config.def.h
index c2a23fa..4e5e3e7 100644
--- a/config.def.h
+++ b/config.def.h
@@ -4,8 +4,11 @@
 /* Default settings; can be overrided by command line. */
 
 static Bool topbar = True;                  /* -b  option; if False, dmenu appears at bottom */
-static const char *font = NULL;             /* -fn option; default X11 font or font set      */
-static const char *prompt = NULL;           /* -p  option; prompt to the elft of input field */
+/* -fn option overrides fonts[0]; default X11 font or font set */
+static const char *fonts[] = {
+	"monospace:size=10"
+};
+static const char *prompt      = NULL;      /* -p  option; prompt to the elft of input field */
 static const char *normbgcolor = "#222222"; /* -nb option; normal background                 */
 static const char *normfgcolor = "#bbbbbb"; /* -nf option; normal foreground                 */
 static const char *selbgcolor  = "#005577"; /* -sb option; selected background               */
@@ -13,5 +16,4 @@ static const char *selfgcolor  = "#eeeeee"; /* -sf option; selected foreground
 static const char *outbgcolor  = "#00ffff";
 static const char *outfgcolor  = "#000000";
 /* -l option; if nonzero, dmenu uses vertical list with given number of lines */
-static unsigned int lines = 0;
-
+static unsigned int lines      = 0;